@@ -91,7 +91,6 @@ class GymTask(TaskType):
         self.skip_start_frames = skip_start_frames
 
         self.seed(kwargs.get('seed'))
-        self.hooks = {}
 
     @staticmethod
     def __determine_action_size(action_space):
@@ -113,10 +112,6 @@ class GymTask(TaskType):
         if self.state_transform is not None:
             state = self.state_transform(state)
 
-        if 'post_reset_hook' in self.hooks:
-            self.hooks['post_reset_hook'](self)
-
-        # self.env.step(2)
         return state
 
     def render(self, mode="rgb_array"):
